import { 
  select, 
  csv, 
  scaleLinear, 
  scaleBand, 
  max, 
	axisLeft,
  axisBottom,
  format
	} from 'd3'

const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');


const render = (data) => {
  const xValue = d => d.population;
  const yVAlue = d => d.country; 
 	const margin = { left: 135, right: 30, top: 45, botton: 80 };
	const innerWidth = width - margin.left - margin.right;
	const innerHeight = height - margin.top - margin.botton;
  
  
	const xScale = scaleLinear()
  	.domain([0, max(data, xValue)])
  	.range([0, innerWidth]);
  
  const yScale = scaleBand()
  	.domain(data.map(yVAlue))
  	.range([0, innerHeight])
  	.padding(0.1);

  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const xAxisTickFormat = number => 
    format(".3s")(number)
      .replace('G', 'B');
  
 const xAxis = axisBottom(xScale)
  	.tickFormat(xAxisTickFormat)
  	.tickSize(-innerHeight);
  
  g.append('g')
    .call(axisLeft(yScale))
  	.selectAll('.domain, .tick line')
  		.remove();
  
  
  const xAxisG =  g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  xAxisG.selectAll('.domain').remove();
  
  
  //criando nossa bar
  g.selectAll('rect').data(data)
  	.enter().append('rect')
  		.attr('y', d => yScale(yVAlue(d)))
  		.attr('width', d => xScale(xValue(d)))
  		.attr('height', yScale.bandwidth());
  
  //Inserindo texto no grupo
  g.append('text')
  	.attr('class', 'title')
  	.text('Top 10 most Populous Countries')
  	.attr('y', -10);
  
  //Texto legenda para o eixo x
  xAxisG.append('text')
  	.text('Population')
  	.attr('class', 'label-bottom')
  	.attr('fill', '#511663')
  	.attr('x', innerWidth / 2)
  	.attr('y', 55)
}


csv('mycsv.csv').then(data => {
  	data.forEach(d => { 
      d.population = +d.population * 1000 
    });
  
		render(data);
})